/**
 * The Election class models an electronic voting system. Election
 * instances can support elections with any number of candidates, 
 * though the number is fixed once an Election object is created.
 * After the candidates' names have been added, users vote by invoking
 * the vote() method and passing in the number of the candidate they
 * wish to vote for. Once the election is over, the printResults()
 * method finds the winner and displays the results.
 * 
 * @author Brad Richards
 * @version 1.0
 */
public class Election {
    
    private String[] candidates; // Array of candidate names
    
    /**
     * The constructor for our Election class.
     * 
     * @param numCandidates  The number of candidates expected for
     *                       this election.
     */
    public Election(int numCandidates) {
        candidates = new String[numCandidates];
    }
    
    /**
     * Allows the user to add candidates to the election (or replace
     * existing candidates with new ones).
     * 
     * @param name   The name of the candidate to be added.
     * @param index  Desired position within candidate list (1-based)
     */
    public void addCandidate(String name, int index) {
        if (index > 0 && index <= candidates.length) {
            candidates[index-1] = name;
        }
    }
    
    /**
     * Prints the names of the candidates, in order.  It uses a for loop
     * instead of a foreach loop since we need to print a candidate number
     * next to each name.  (We could also use a foreach and add a counter
     * like we did on the Notebook lab.)
     */
    public void printCandidates() {
        for(int index = 0; index < candidates.length; index=index+1) {
            System.out.println(index+1 + ") " + candidates[index]);
        }
    }
}